SystemOrganization addCategory: #'Phidget-Tests'!

TestCase subclass: #PhdCrInterfaceKitTest
	instanceVariableNames: 'ifKit'
	classVariableNames: ''
	poolDictionaries: ''
	category: 'Phidget-Tests'!

!PhdCrInterfaceKitTest methodsFor: 'testing' stamp: 'lk 5/28/2009 21:48'!
setUp
	"open an interface kit"
	
	ifKit := PhdCrInterfaceKit new openAny.! !

!PhdCrInterfaceKitTest methodsFor: 'testing' stamp: 'lk 5/28/2009 21:48'!
tearDown
	"close the interface kit"
	
	ifKit close.! !

!PhdCrInterfaceKitTest methodsFor: 'testing - open/close' stamp: 'lk 6/15/2009 12:09'!
testAttach
	"Test attaching an InterfaceKit"
	
	(PhidgetPluginTest questionWithoutCancel: 'Do you want to run the Test "Attach InterfaceKit"?')
		ifTrue: [
			self assert: (PhidgetPluginTest proceed: 'Now detach all InterfaceKits and press OK.').
			self deny: ifKit isAttached.
			self assert: (PhidgetPluginTest proceed: 'Now attach an InterfaceKit and press OK.').
			self assert: ifKit isAttached ].! !

!PhdCrInterfaceKitTest methodsFor: 'testing - open/close' stamp: 'lk 5/31/2009 21:56'!
testClose

	self assert: ifKit isOpen.
	ifKit close.
	self deny: ifKit isOpen.! !

!PhdCrInterfaceKitTest methodsFor: 'testing - open/close' stamp: 'lk 5/31/2009 21:54'!
testResetSemaphores
	"Test if after closing a Phidget all semaphores are reset."
	
	"use the PhdCrPhidget version of this test as we cannot access the handle from here."
	self assert: ifKit isOpen.
	self deny: ifKit testSemaphoresReset.
	ifKit close.
	self assert: ifKit testSemaphoresReset.! !

TestCase subclass: #PhidgetMockTest
	instanceVariableNames: ''
	classVariableNames: ''
	poolDictionaries: ''
	category: 'Phidget-Tests'!

!PhidgetMockTest methodsFor: 'as yet unclassified' stamp: 'pt 8/31/2009 17:24'!
testIncrementID

	| id |
	id := { 0 . 255 . 255 . 254 } asByteArray.
	self assert: ( PhdMockPhidget incrementByteArray: id ) = { 0 . 255 . 255 . 255 } asByteArray.
	
	id := { 0 . 255 . 255 . 255 } asByteArray.
	self assert: ( PhdMockPhidget incrementByteArray: id ) = { 1 . 0 . 0 . 0 } asByteArray.
	! !

TestCase subclass: #PhidgetPluginTest
	instanceVariableNames: ''
	classVariableNames: ''
	poolDictionaries: ''
	category: 'Phidget-Tests'!

!PhidgetPluginTest commentStamp: 'fs 7/24/2009 16:03' prior: 0!
A PhidgetPluginTest is xxxxxxxxx.


!

!PhidgetPluginTest class methodsFor: 'dialogs' stamp: 'lk 5/31/2009 22:01'!
message: text
	"open a modal dialog window with the message in text and an OK Button.
	Return true if the user clicked 'OK', false otherwise."
	
	^ (Morph new openModal: 
		(MessageDialogWindow new
			textFont: Preferences standardDefaultTextFont;
			title: 'Running Phidget Tests';
			text: text)
		) cancelled not.! !

!PhidgetPluginTest class methodsFor: 'dialogs' stamp: 'lk 5/31/2009 22:01'!
proceed: text
	"open a modal dialog window with the message in text and a Cancel button.
	Return false if the user clicked 'Cancel', true otherwise."
	
	^ (Morph new openModal: 
		(ProceedDialogWindow new
			textFont: Preferences standardDefaultTextFont;
			title: 'Running Phidget Tests';
			text: text)
		) cancelled not.! !

!PhidgetPluginTest class methodsFor: 'dialogs' stamp: 'lk 5/31/2009 22:01'!
questionWithoutCancel: text
	"Show a modal dialog window asking the question is text and Buttons for Yes and No.
	Return true if the user clicked 'yes', false otherwise."
	
	^ (Morph new openModal: 
		(QuestionWithoutCancelDialogWindow new
			textFont: Preferences standardDefaultTextFont;
			title: 'Running Phidget Tests';
			text: text)
		) answer.! !

!PhidgetPluginTest methodsFor: 'testing - close all' stamp: 'lk 7/7/2009 19:43'!
testCloseAllPhidgets
	"after closing all Phidgets there should be no more Phidgets open."
	
	PhdCrPhidget allOpenedPhidgets do: [ :phidget | phidget close ].
	self assert: PhdCrPhidget allOpenedPhidgets size == 0.! !
